import { main } from '@/api'
import request from '@/utils/require'

export function selectNoticePageList(data) {
    return request({
        url: `${main}/transaction/notice/selectNoticePageList?pageNum=${data.pageNum}&pageSize=${data.pageSize}`,
        method: 'post',
        data: data
    })
}

//删除
export function deleteNotice(data) {
    return request({
        url: `${main}/transaction/notice/deleteNotice`,
        method: 'post',
        data: data
    })
}



//新增
export function insertNotice(data) {
    return request({
        url: `${main}/transaction/notice/insertNotice`,
        method: 'post',
        data: data
    })
}

//修改
export function updateNotice(data) {
    return request({
        url: `${main}/transaction/notice/updateNotice`,
        method: 'post',
        data: data
    })
}

//详情
export function selectNoticeDetail(data) {
    return request({
        url: `${main}/transaction/notice/selectNoticeDetail`,
        method: 'post',
        data: data
    })
}

//场次下拉
export function selectSiteAll(data) {
    return request({
        url: `${main}/transaction/notice/selectSiteAllNotice`,
        method: 'post',
        data: data
    })
}


//合同下拉
export function selectContracts(ccbm) {
    return request({
        url: `${main}/transaction/notice/selectContractNotice/${ccbm}`,
        method: 'get'
    })
}

//合同
export function selectContractDetail(id) {
    return request({
        url: `${main}/transaction/trademark/selectContractDetail/${id}`,
        method: 'post'
    })
}